==> go.php?file=RaidSlackCheck1.32.zip: RaidSlackCheck/Localization/localization-frFR.lua <==
﻿if GetLocale() == "frFR" then

function rsclocalel()


	psfpotchecklocal = "Vérifier les potions"
	psfpotchecklocalt2 = "Vérifier les flacons"
	psfpotchecklocalt3 = "Renaissance - Rebuff"
	psfpotchecklocalt322 = "Vérifier les buffs après une Renaissance en combat"
	rscaddonnotworkinz = "L'addon est activé dans certaines zones :"
	rscbuffnameslitnew1 = "5% stats"
	rscbuffnameslitnew2 = "Endurance"
	rscbuffnameslitnew3 = "Protection contre l'Ombre"
	rscbuffnameslitnew4 = "Intelligence"
	rscbuffnameslitnew5 = "Bénédiction de puissance"
	rscbuffspart1 = "Ce module vérifie les buffs qui ont été choisis dans"
	rscbuffspart2 = "après une Renaissance et des rapports manquants, alors - Revérifiez à nouveau"
	rscbuffspart3 = "Vous pouvez définir des responsables pour les buffs, un whisp leur sera envoyé à la première vérification, s'ils sont en vie dans le raid, et le cas échéant, à toutes les personnes qui peuvent buff."
	rscbuttonreset = "Réinitialiser"
	rscbuttonztext1 = "Ajouter la zone actuelle"
	rscbuttonztext2 = "Effacer la zone actuelle"
	rscbuttonztext3 = "Voir la liste"
	rscbuttonztext4 = "Réinitialiser la liste"
	rscchatlist1 = "raid"
	rscchatlist2 = "avertissement raid"
	rscchatlist3 = "officier"
	rscchatlist4 = "groupe"
	rscchatlist5 = "guilde"
	rscchatlist6 = "dire/dit"
	rscchatlist7 = "crier/crie"
	rscchatlist8 = "sur soi seulement"
	rscflasktext1 = "En plus de la vérification classique des flacons & buffs nourriture, ce module propose des options de contrôle automatique des buffs et de signalement des absents au démarrage d'un combat contre un boss, le contrôle à l'appel, ou un timer de pull ou début de combat (en utilisant l'addon PhoenixStyle) (une vérification max toutes les 50 secs sauf au démarrage du combat)."
	rscflasktext10 = "Tout le monde a un flacon et le buff nourriture."
	rscflasktext11 = "Tout le monde a un flacon."
	rscflasktext12 = "Aucune donnée. Il y a trop de mort/déconnecté"
	rscflasktext1part2 = "Le Buff n'est pas considéré si le temps restant est inférieur à |cffff0000%s|r min."
	rscflasktext2 = "canal de discussion pour le contrôle automatique :"
	rscflasktext3 = "Vérifier en premier"
	rscflasktext4 = "Seulement un Elixir"
	rscflasktext5 = "Pas de Flacon"
	rscflasktext555 = "Ancien flacon"
	rscflasktext6 = "personne ne l'a"
	rscflasktext7 = "Pas de buff nourriture"
	rscflasktext8 = "Buff nourriture seulement sur"
	rscflasktext9 = "Non vérifié"
	rscflasktextc11 = "annoncer au moment de l'attaque du boss"
	rscflasktextc12 = "annoncer quand le timer du pull est lancé"
	rscflasktextc13 = "annoncer quand l'appel est lancé"
	rscflasktextc14 = "Envoyer des whisp lors de la vérification automatique"
	rscflasktextc15 = "vérifier les buffs nourriture"
	rscflasktxtgroup2 = "groupes"
	rscflasktxtgroup5 = "groupes"
	rscflaskwhisptxt1 = "RSC > Vous n'avez pas de buff nourriture !"
	rscflaskwhisptxt11 = "RSC > Votre buff nourriture va bientôt expirer."
	rscflaskwhisptxt2 = "RSC > Vous n'utilisez qu'un Élixir seul !"
	rscflaskwhisptxt3 = "RSC > Vous n'avez ni Flacon ni Élixir !"
	rscflaskwhisptxt33 = "RSC > Votre flacon va bientôt expirer."
	rscflaskwhisptxt4 = "RSC > Vous n'avez pas de buff nourriture et seulement un élixir actif !"
	rscflaskwhisptxt40 = "RSC > Vous n'avez pas de buff nourriture et votre flacon va bientôt expirer."
	rscflaskwhisptxt44 = "RSC > Votre buff nourriture va bientôt expirer et vous avez seulement 1 élixir !"
	rscflaskwhisptxt5 = "RSC > Vous n'avez ni Flacon ni Buff Nourriture !"
	rscflaskwhisptxt55 = "RSC > Vous n'avez pas de flacon et votre buff nourriture va bientôt expirer !"
	rscflaskwhisptxt56 = "RSC > Votre buff nourriture et votre flacon vont bientôt expirer."
	rscfoodstillthere = "Le festin est toujours présent"
	rsclocallpot = "toutes les potions"
	rscloccolor = "couleurs des noms"
	rsclocfight1 = "dernier combat"
	rsclocfight2 = "combat précédent"
	rsclocfight3 = "combat"
	rscloclastf = "dernier combat"
	rsclocnotinc = "hors combat"
	rsclocpot10 = "Qui a utilisé une potion"
	rsclocpot11 = "Qui n'a pas utilisé"
	rsclocpot12 = "Potions avant le combat précédent"
	rsclocpot13 = "Ont utilisé des potions avant le combat précédent"
	rsclocpot14 = "Personne n'a utilisé de potion pour le combat précédent."
	rsclocpot15 = "Potions utilisées avant le combat précédent seulement"
	rsclocpot16 = "Aucune potion avant le combat précédent"
	rsclocpot17 = "Personne n'a utilisé de potion"
	rsclocpot18 = "Potions utilisées"
	rsclocpot2 = "Aucune potion sélectionnée"
	rsclocpot3 = "Aucune potion"
	rsclocpot4 = "Tout le monde a utilisé une potion"
	rsclocpot5 = "Information sur "
	rsclocpot6 = "Aucune potion :"
	rsclocpot7 = "Aucun fainéant repéré"
	rsclocpot8 = "Autres potions utilisées :"
	rsclocpot9 = "Aucune autre potion n'a été utilisée."
	rsclocpoths17 = "Personne n'a utilisé de pierre de soin"
	rsclocpoths172 = "Tout le monde a utilisé une Pierre de soin"
	rsclocpoths18 = "ont utilisés des pierres de soin"
	rsclocpoths182 = "Pierres de soins non utilisées"
	rsclocrep1 = "Rapport dans la fenêtre de discussion :"
	rsclocrlslak = "Reporter les fainéants au responsable du raid"
	rscmanualsend = "envoi manuel :"
	rscmin = "minutes"
	rsconlybossfig1 = "Maintenant les potions utilisées seront vérifiées uniquement sur les combat contre des boss"
	rsconlybossfig2 = "Maintenant les potions utilisées seront vérifiées durant tous les combats"
	rsconlybossfigtloc = "seulement les combat contre des boss"
	rscpartanons31 = "Annoncer sur le canal au bout d'une vérification"
	rscpartanons32 = "Annoncer sur le canal au bout de deux vérifications"
	rscpartanons33 = "envoyer des whisps au bout d'une vérification"
	rscpartanons34 = "envoyer des whisps au bout de deux vérifications"
	rscpartanons35 = "Annoncer sans promotion"
	rscpartanons36 = "en cas d'utilisation d'élixirs, vérifiez que 2 sont présents et non pas 1 seulement"
	rscparton3 = "ACTIVE"
	rscpartwhobuff1 = "Responsables des buffs :"
	rscreleasedtxt1 = "a été ressuscité"
	rscreleasedtxt1f = "a été ressuscité"
	rscreleasedtxt2 = "il y a"
	rscreleasedtxt3 = "Manquant"
	rscreleasedtxt4 = "TOUJOURS MANQUANT"
	rscreleasedtxt5 = "Deuxième vérification"
	rscreleasedtxt6 = "mais est toujours manquant"
	rscreleasedtxt6f = "mais est toujours manquant"
	rscreleasedtxt7 = "mais manquant"
	rscreleasedtxt7f = "mais manquant"
	rscreloadbutton = "Mise à jour"
	rscsec = "sec."
	rscsend = "Mettre à jour et poster sur le canal"
	rsctablereptxt1 = "Annoncer quand quelqu'un pose un festin"
	rsctablereptxt2 = "Annoncer quand quelqu'un pose un chaudron de guilde"
	rsctablereptxt3 = "Annoncer quand quelqu'un pose un robot réparateur"
	rsctablereptxt4 = "Annoncer quand un démoniste invoque un Puits des âmes"
	rsctableused1 = "a posé un festin"
	rsctableused2 = "a posé un Chaudron de guilde"
	rsctableused3 = "a posé un robot réparateur"
	rsctableused4 = "invoque un Puits des âmes"
	rscwhousehstext = "a utilisé une pierre de soin"
	rscwhousehstext2 = "Pierre de soin non utilisée"
	rsczonereport1 = "L'addon est activé dans :"
	rsczonereport2 = "L'addon va maintenant fonctionner dans la zone :"
	rsczonereport3 = "L'addon ne fonctionne pas dans :"
	rsczonereport5 = "La liste est maintenant vide ! L'addon NE fonctionnera PLUS dans aucune instances !"
	rsczonereport6 = "liste vide"
	rsczonereport7 = "|cffff0000Erreur !|r La zone actuelle est déjà dans la liste !"
	rsczonereport8 = "|cffff0000Erreur !|r La zone actuelle n'a pas été trouvée dans la liste !"
	rsczonereport9 = "Pour réinitialiser la liste noire - cliquez sur le bouton |cffff0000TWICE|r"



end


end

==> go.php?file=RaidSlackCheck1.252.zip: RaidSlackCheck/Localization/localization-frFR.lua <==
﻿if GetLocale() == "frFR" then

function rsclocalel()


	psfpotchecklocal = "Vérifier les potions"
	psfpotchecklocalt2 = "Vérifier les flacons"
	psfpotchecklocalt3 = "Renaissance - Rebuff"
	psfpotchecklocalt322 = "Vérifier les buffs après une Renaissance en combat"
	rscaddonnotworkinz = "L'addon est activé dans certaines zones :"
	rscbuffnameslitnew1 = "5% stats"
	rscbuffnameslitnew2 = "Endurance"
	rscbuffnameslitnew3 = "Protection contre l'Ombre"
	rscbuffnameslitnew4 = "Intelligence"
	rscbuffnameslitnew5 = "Bénédiction de puissance"
	rscbuffspart1 = "Ce module vérifie les buffs qui ont été choisis dans"
	rscbuffspart2 = "après une Renaissance et des rapports manquants, alors - Revérifiez à nouveau"
	rscbuffspart3 = "Vous pouvez définir des responsables pour les buffs, puis s'ils sont vivants lors d'un raid - à la première vérification un murmure sera envoyer seulement pour eux, sinon - à toutes les personnes qui peuvent buff."
	rscbuttonreset = "Réinitialiser"
	rscbuttonztext1 = "Ajouter la zone actuelle"
	rscbuttonztext2 = "Effacer la zone actuelle"
	rscbuttonztext3 = "Voir la liste"
	rscbuttonztext4 = "Réinitialiser la liste"
	rscchatlist1 = "raid"
	rscchatlist2 = "avertissement raid"
	rscchatlist3 = "officier"
	rscchatlist4 = "groupe"
	rscchatlist5 = "guilde"
	rscchatlist6 = "dire/dit"
	rscchatlist7 = "crier/crie"
	rscchatlist8 = "sur soi seulement"
	rscflasktext1 = "Sauf la vérification de flacon normal & nourriture, ce module propose des options uniques d'auto-contrôle et de rapport de fainéants au démarrage d'un combat contre un boss, la vérification de départ ou un timer de charge (en utilisant l'addon PhoenixStyle) (une vérification max toutes les 50 secs sauf au démarrage du combat)."
	rscflasktext10 = "Tout le monde a un flacon et le buff nourriture."
	rscflasktext11 = "Tous le monde a un flacon."
	rscflasktext12 = "Aucune donnée. Il y a trop de mort/déconnecté"
	rscflasktext1part2 = "Le Buff n'est pas considéré si le temps restant est inférieur à |cffff0000%s|r min."
	rscflasktext2 = "canal de discussion pour l'auto-vérification :"
	rscflasktext3 = "Vérifier en premier"
	rscflasktext4 = "Seulement un Elixir"
	rscflasktext5 = "Pas de Flacon"
	rscflasktext6 = "personne ne l'a"
	rscflasktext7 = "Pas de buff nourriture"
	rscflasktext8 = "Le buff nourriture seulement sur"
	rscflasktext9 = "Pas vérifié"
	rscflasktextc11 = "annoncer au moment de l'attaque du boss"
	rscflasktextc12 = "annoncer quand le chrono pour Pull est lancé"
	rscflasktextc13 = "annoncé quand la 'Vérification' est lancé"
	rscflasktextc14 = "Envoyer des chuchotement sur la vérification automatique"
	rscflasktextc15 = "vérifier la nourriture"
	rscflasktxtgroup2 = "groupes"
	rscflasktxtgroup5 = "groupes"
	rscflaskwhisptxt1 = "RSC > Vous n'avez pas de buff nourriture !"
	rscflaskwhisptxt11 = "RSC > Votre buff nourriture va bientôt expirer."
	rscflaskwhisptxt2 = "RSC > Vous avez utilisé seulement 1 Élixir !"
	rscflaskwhisptxt3 = "RSC > Vous avez ni Flacon ou Élixir !"
	rscflaskwhisptxt33 = "RSC > Votre flacon va bientôt expirer."
	rscflaskwhisptxt4 = "RSC > Vous n'avez pas de buff nourriture et seulement 1 élixir !"
	rscflaskwhisptxt40 = "RSC > Vous n'avez pas de buff nourriture et votre flacon va bientôt expirer."
	rscflaskwhisptxt44 = "RSC > Votre buff nourriture va bientôt expirer et vous avez seulement 1 élixir !"
	rscflaskwhisptxt5 = "RSC > Vous avez ni Flacon ni Buff Nourriture !"
	rscflaskwhisptxt55 = "RSC > Vous n'avez pas de flacon et votre buff nourriture va bientôt expirer !"
	rscflaskwhisptxt56 = "RSC > Votre buff nourriture et flacon vont bientôt expirer."
	rsclocallpot = "toutes les potions"
	rscloccolor = "couleurs des noms"
	rsclocfight1 = "dernier combat"
	rsclocfight2 = "combat précédent"
	rsclocfight3 = "combat"
	rscloclastf = "dernier combat"
	rsclocnotinc = "hors combat"
	rsclocpot10 = "Qui a utilisé une potion"
	rsclocpot11 = "Qui n'a pas utilisé"
	rsclocpot12 = "Potions avant le combat précédent"
	rsclocpot13 = "Ont utilisé des potions avant le combat précédent :"
	rsclocpot14 = "Personne n'a utilisé de potion pour le combat précédent."
	rsclocpot15 = "Potions utilisées avant le combat précédent seulement"
	rsclocpot16 = "Aucune potion avant le combat précédent :"
	rsclocpot17 = "Personne n'a utilisé de potion"
	rsclocpot18 = "Potions utilisées"
	rsclocpot2 = "Aucune potion sélectionnée"
	rsclocpot3 = "Aucune potion"
	rsclocpot4 = "Tout le monde a utilisé une potion"
	rsclocpot5 = "Information sur "
	rsclocpot6 = "Aucune potion :"
	rsclocpot7 = "Aucun fainéant repéré"
	rsclocpot8 = "Autres potions utilisées :"
	rsclocpot9 = "Aucune autre potion n'a été utilisée."
	rsclocrep1 = "Rapport dans la fenêtre de discussion :"
	rsclocrlslak = "Reporter les fainéants au responsable du raid"
	rscmanualsend = "envoi manuel :"
	rscmin = "minutes"
	rsconlybossfig1 = "Maintenant les potions utilisées seront vérifiées seulement sur les combat contre les boss"
	rsconlybossfig2 = "Maintenant les potions utilisées seront vérifiées durant tous les combats"
	rsconlybossfigtloc = "seulement les combat contre les boss"
	rscpartanons31 = "Annoncer sur le canal au bout d'1 vérification"
	rscpartanons32 = "Annoncer sur le canal au bout de 2 vérifications"
	rscpartanons33 = "envoyer des chuchotements au bout d'1 vérification"
	rscpartanons34 = "envoyer des chuchotements au bout de 2 vérifications"
	rscpartanons35 = "Annoncer sans promotion"
	rscpartanons36 = "en cas d'utilisation d'élixirs, vérifiez que 2 sont présents et non pas 1 seulement"
	rscparton3 = "ACTIVE"
	rscpartwhobuff1 = "Responsables des buffs :"
	rscreleasedtxt1 = "a été ressuscité"
	rscreleasedtxt1f = "a été ressuscité"
	rscreleasedtxt2 = "il y a"
	rscreleasedtxt3 = "Manquant"
	rscreleasedtxt4 = "TOUJOURS MANQUANT"
	rscreleasedtxt5 = "Deuxième vérification"
	rscreleasedtxt6 = "mais est toujours manquant"
	rscreleasedtxt6f = "mais est toujours manquant"
	rscreleasedtxt7 = "mais manquant"
	rscreleasedtxt7f = "mais manquant"
	rscreloadbutton = "Mise à jour"
	rscsec = "sec."
	rscsend = "Mettre à jour et Envoyer"
	rsczonereport1 = "L'addon est activé dans :"
	rsczonereport2 = "L'addon va maintenant fonctionner dans la zone :"
	rsczonereport3 = "L'addon ne fonctionne pas dans :"
	rsczonereport5 = "La liste est maintenant vide ! L'addon NE fonctionnera PAS maintenant dans toutes les instances !"
	rsczonereport6 = "liste vide"
	rsczonereport7 = "|cffff0000Erreur !|r La zone actuelle est déjà dans la liste !"
	rsczonereport8 = "|cffff0000Erreur !|r La zone actuelle n'a pas été trouvée dans la liste !"
	rsczonereport9 = "Pour réinitialiser la liste noire - cliquez le bouton |cffff0000TWICE|r"



end


end
